@@ -54,17 +54,26 @@
 #'   in description text.
 #' @returns
 #'   An object of class "light_breakdown" with the following elements:
-#'   - `data` A tibble with results. Can be used to build fully customized
-#'     visualizations. Column names can be controlled by `options(flashlight.column_name)`.
+#'   - `data` A tibble with results.
 #'   - `by` Same as input `by`.
 #' @export
 #' @references
 #'   A. Gosiewska and P. Biecek (2019). IBREAKDOWN: Uncertainty of model explanations
 #'     for non-additive predictive models. ArXiv.
 #' @examples
-#' fit <- lm(Sepal.Length ~ . + Petal.Length:Species, data = iris)
-#' fl <- flashlight(model = fit, label = "lm", data = iris, y = "Sepal.Length")
-#' light_breakdown(fl, new_obs = iris[1, ])
+#' fit_part <- lm(Sepal.Length ~ Species + Petal.Length, data = iris)
+#' fl_part <- flashlight(
+#'   model = fit_part, label = "part", data = iris, y = "Sepal.Length"
+#' )
+#' plot(light_breakdown(fl_part, new_obs = iris[1, ]))
+#'
+#' # Second model
+#' fit_full <- lm(Sepal.Length ~ ., data = iris)
+#' fl_full <- flashlight(
+#'   model = fit_full, label = "full", data = iris, y = "Sepal.Length"
+#' )
+#' fls <- multiflashlight(list(fl_part, fl_full))
+#' plot(light_breakdown(fls, new_obs = iris[1, ]))
 #' @seealso [plot.light_breakdown()]
 light_breakdown <- function(x, ...) {
   UseMethod("light_breakdown")
@@ -88,37 +97,16 @@ light_breakdown.flashlight <- function(x, new_obs, data = x$data, by = x$by,
                                        description = TRUE, digits = 2, ...) {
   visit_strategy <- match.arg(visit_strategy)
 
-  warning_on_names(
-    c(
-      "after_name",
-      "before_name",
-      "description_name",
-      "variable_name"
-    ),
-    ...
-  )
-
-  after_name <- getOption("flashlight.after_name")
-  before_name <- getOption("flashlight.before_name")
-  description_name <- getOption("flashlight.description_name")
-  label_name <- getOption("flashlight.label_name")
-  step_name <- getOption("flashlight.step_name")
-  variable_name <- getOption("flashlight.variable_name")
-
   stopifnot(
     "No data!" = is.data.frame(data) && nrow(data) >= 1L,
     "'by' not in 'data'!" = by %in% colnames(data),
     "Not all 'v' in 'data'" = v %in% colnames(data),
     "'new_obs' has to consist of one row" = nrow(new_obs) == 1L,
     "'new_obs' not consistent with 'data'" =
-      sort(colnames(new_obs)) == sort(colnames(data))
-  )
-  check_unique(
-    opt_names = c(
-      after_name, before_name, label_name, variable_name, description_name
-    )
-  )
+      sort(colnames(new_obs)) == sort(colnames(data)),
+    !any(c("after_", "before_", "description_", "label_", "step_", "variable_") %in% by)
 
+  )
   if (!is.null(seed)) {
     set.seed(seed)
   }
@@ -127,7 +115,8 @@ light_breakdown.flashlight <- function(x, new_obs, data = x$data, by = x$by,
   if (length(by)) {
     data <- dplyr::semi_join(data, new_obs, by = by)
   }
-  stopifnot((n <- nrow(data)) >= 1L)
+  n <- nrow(data)
+  stopifnot(n >= 1L)
 
   # Subsample to n_max
   if (n > n_max) {
@@ -145,8 +134,10 @@ light_breakdown.flashlight <- function(x, new_obs, data = x$data, by = x$by,
   if (is.null(v)) {
     v <- setdiff(colnames(data), c(x$y, by, x$w))
   }
+
+  m <- length(v)
   stopifnot(
-    (m <- length(v)) >= 1L,
+    m >= 1L,
     !(c("baseline", "prediction") %in% v)
   )
 
@@ -182,13 +173,12 @@ light_breakdown.flashlight <- function(x, new_obs, data = x$data, by = x$by,
 
   # Combine results
   out <- tibble::tibble(
-    0:(m + 1L),
-    c("baseline", v, "prediction"),
-    c(baseline, mean_pred_vector, prediction)
+    step_ = 0:(m + 1L),
+    variable_ = c("baseline", v, "prediction"),
+    after_ = c(baseline, mean_pred_vector, prediction),
+    before_ = dplyr::lag(after_, default = baseline),
+    label_ = x$label
   )
-  colnames(out) <- c(step_name, variable_name, after_name)
-  out[[before_name]] <- dplyr::lag(out[[after_name]], default = baseline)
-  out[[label_name]] <- x$label
 
   if (description) {
     # Helper function
@@ -205,20 +195,19 @@ light_breakdown.flashlight <- function(x, new_obs, data = x$data, by = x$by,
     formatted_input <- c(
       "average in data", paste(v, formatted_input, sep = " = "), "prediction"
     )
-    formatted_impact <-
-      out[[after_name]] - ifelse(out[[step_name]] > 0, out[[before_name]], 0)
-    plus_sign <- formatted_impact >= 0 & out[[step_name]] > 0
+    formatted_impact <- out$after_ - ifelse(out$step_ > 0, out$before_, 0)
+    plus_sign <- formatted_impact >= 0 & out$step_ > 0
     formatted_impact <- paste0(
       ifelse(plus_sign, "+", ""), .pretty_num(formatted_impact)
     )
-    out[[description_name]] <- paste(formatted_input, formatted_impact, sep = ": ")
+    out$description_ <- paste(formatted_input, formatted_impact, sep = ": ")
   } else {
-    out[[description_name]] <- ""
+    out$description_ <- ""
   }
 
   # Organize output
   if (length(by)) {
-    out[, by] <- new_obs[rep(1, nrow(out)), by, drop = FALSE]
+    out[, by] <- new_obs[rep(1L, nrow(out)), by, drop = FALSE]
   }
   add_classes(list(data = out, by = by), c("light_breakdown", "light"))
 }
@@ -231,6 +220,68 @@ light_breakdown.multiflashlight <- function(x, ...) {
                 new_class = "light_breakdown_multi")
 }
 
+#' Visualize Variable Contribution Breakdown for Single Observation
+#'
+#' Minimal visualization of an object of class "light_breakdown" as waterfall plot.
+#' The object returned is of class "ggplot" and can be further customized.
+#'
+#' The waterfall plot is to be read from top to bottom.
+#' The first line describes the (weighted) average prediction in the query data
+#' used to start with. Then, each additional line shows how the prediction changes
+#' due to the impact of the corresponding variable.
+#' The last line finally shows the original prediction of the selected observation.
+#' Multiple flashlights are shown in different facets.
+#' Positive and negative impacts are visualized with different colors.
+#'
+#' @importFrom rlang .data
+#'
+#' @inheritParams plot.light_performance
+#' @param x An object of class "light_breakdown".
+#' @param facet_ncol `ncol` argument passed to [ggplot2::facet_wrap()].
+#' @param ... Further arguments passed to [ggplot2::geom_label()].
+#' @returns An object of class "ggplot".
+#' @export
+#' @seealso [light_breakdown()]
+plot.light_breakdown <- function(x, facet_scales = "free",
+                                 facet_ncol = 1, rotate_x = FALSE, ...) {
+  stopifnot(!(c("fill_", "xmin_", "xmax_", "y_") %in% colnames(x$data)))
+  data <- transform(
+    x$data,
+    fill_ = (after_ - before_) > 0,
+    ymin_ = step_ - 0.5,
+    ymax_ = step_ + 0.5,
+    x_ = pmin(before_, after_)
+  )
+
+  p <- ggplot2::ggplot(
+    data,
+    ggplot2::aes(
+      x = x_, y = step_, xmin = before_, xmax = after_, ymin = ymin_, ymax = ymax_
+    )
+  ) +
+    ggplot2::geom_rect(
+      ggplot2::aes(fill = fill_), color = "black", show.legend = FALSE
+    ) +
+    ggplot2::labs(x = "Prediction", y = NULL) +
+    ggplot2::geom_label(ggplot2::aes(label = description_), hjust = -0.05, ...) +
+    ggplot2::scale_x_continuous(expand = ggplot2::expansion(mult = c(0, 0.67))) +
+    ggplot2::scale_y_reverse() +
+    ggplot2::theme(
+      panel.grid.major.y = ggplot2::element_blank(),
+      panel.grid.minor.y = ggplot2::element_blank(),
+      axis.text.y = ggplot2::element_blank(),
+      axis.ticks.y = ggplot2::element_blank()
+    )
+
+  if (is.light_breakdown_multi(x)) {
+    p <- p + ggplot2::facet_wrap(~label_, scales = facet_scales, ncol = facet_ncol)
+  }
+  if (rotate_x) {
+    p <- p + rotate_x()
+  }
+  p
+}
+
 # Helper function
 .mean_pred <- function(x, data, w = if (!is.null(x$w)) data[[x$w]]) {
   MetricsWeighted::weighted_mean(stats::predict(x, data = data), w = w, na.rm = TRUE)
